@@ -15,7 +15,8 @@ class ROT2Prog:
 	    min_az (float): Minimum azimuth angle.
 	    min_el (float): Minimum elevation angle.
 	"""
-	
+
+	_log = logging.getLogger(__name__)
 	_ser = None
 	_resolution = 1
 
@@ -31,43 +32,19 @@ class ROT2Prog:
 		    port (str): Name of serial port to connect to.
 		    timeout (int, optional): Worst case response time of the controller.
 		"""
-
 		# open serial port
-		while(self._ser is None):
-			try:
-				self._ser = serial.Serial(
-					port = port,
-					baudrate = 600,
-					bytesize = 8,
-					parity = 'N',
-					stopbits = 1,
-					timeout = timeout)
-			except:
-				# retry until connection is established
-				logging.error('Connection to serial port failed, retrying in ' + str(timeout) + ' seconds...')
-				time.sleep(timeout)
+		self._ser = serial.Serial(
+			port = port,
+			baudrate = 600,
+			bytesize = 8,
+			parity = 'N',
+			stopbits = 1,
+			timeout = timeout)
 
-		logging.info('ROT2Prog interface opened on ' + str(self._ser.name) + '\n')
+		self._log.info('ROT2Prog interface opened on ' + str(self._ser.name))
 
 		# get resolution from controller
 		self.status()
-	
-	def __del__(self):
-		"""Closes serial connection and deletes object.
-		"""
-		if(self._ser is not None):
-			self._ser.close()
-
-	def _help(self):
-		"""Displays a help message for standalone commands.
-		"""
-		print('\n##############################')
-		print('# ROT2Prog Interface Commands')
-		print('##############################')
-		print('# stop')
-		print('# status')
-		print('# set [azimuth] [elevation]')
-		print('##############################\n')
 
 	def _send_command(self, cmd):
 		"""Sends a command packet.
@@ -77,7 +54,7 @@ class ROT2Prog:
 		"""
 		self._ser.flush()
 		self._ser.write(bytearray(cmd))
-		logging.debug('Command packet sent: ' + str(cmd) + '\n')
+		self._log.debug('Command packet sent: ' + str(cmd))
 
 	def _recv_response(self):
 		"""Receives a response packet.
@@ -89,14 +66,14 @@ class ROT2Prog:
 		response_packet = list(self._ser.read(12))
 
 		# attempt to receive 12 bytes (length of response packet)
-		if(len(response_packet) != 12):
-			if(len(response_packet) == 0):
-				logging.error('Response timed out\n')
+		if len(response_packet) != 12:
+			if len(response_packet) == 0:
+				self._log.error('Response timed out')
 			else:
-				logging.error('Invalid response packet\n')
+				self._log.error('Invalid response packet')
 			return [0, 0]
 		else:
-			logging.debug('Response packet received: ' + str(list(response_packet)) + '\n')
+			self._log.debug('Response packet received: ' + str(list(response_packet)))
 
 			# convert from byte values
 			az = (response_packet[1] * 100) + (response_packet[2] * 10) + response_packet[3] + (response_packet[4] / 10) - 360.0
@@ -106,19 +83,16 @@ class ROT2Prog:
 
 			# check resolution value
 			valid_resolution = [0x1, 0x2, 0x4]
-			if(PH != PV or PH not in valid_resolution):
-				logging.error('Invalid controller resolution [PH = ' + str(hex(PH)) + ', PV = ' + str(hex(PV)) + ']\n')
+			if PH != PV or PH not in valid_resolution:
+				self._log.error('Invalid controller resolution [PH = ' + str(hex(PH)) + ', PV = ' + str(hex(PV)) + ']')
 			else:
 				self._resolution = PH
 
-			logging.info('##############################')
-			logging.info('# RESPONSE')
-			logging.info('##############################')
-			logging.info('# Azimuth:   ' + str(round(float(az), 2)))
-			logging.info('# Elevation: ' + str(round(float(el), 2)))
-			logging.info('# PH: ' + str(PH))
-			logging.info('# PV: ' + str(PV))
-			logging.info('##############################\n')
+			self._log.debug('Received response')
+			self._log.debug('-> Azimuth:   ' + str(round(float(az), 2)))
+			self._log.debug('-> Elevation: ' + str(round(float(el), 2)))
+			self._log.debug('-> PH:        ' + str(PH))
+			self._log.debug('-> PV:        ' + str(PV))
 
 			return [az, el]
 
@@ -128,9 +102,7 @@ class ROT2Prog:
 		Returns:
 		    list of float: List containing azimuth and elevation.
 		"""
-		logging.info('##############################')
-		logging.info('# STATUS COMMAND')
-		logging.info('##############################\n')
+		self._log.debug('Status command to be sent')
 
 		cmd = [0x57, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0x20]
 		self._send_command(cmd)
@@ -142,9 +114,7 @@ class ROT2Prog:
 		Returns:
 		    list of float: List containing azimuth and elevation.
 		"""
-		logging.info('##############################')
-		logging.info('# STOP COMMAND')
-		logging.info('##############################\n')
+		self._log.debug('Stop command to be sent')
 
 		cmd = [0x57, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0f, 0x20]
 		self._send_command(cmd)
@@ -158,28 +128,25 @@ class ROT2Prog:
 		    el (float): Elevation angle to turn rotator to.
 		"""
 		# make sure the inputs are within bounds and correct violations
-		if(az > self.max_az):
-			while(az > self.max_az):
+		if az > self.max_az:
+			while az > self.max_az:
 				az -= 360
-			logging.warning('Azimuth corrected to: ' + str(round(float(az), 2)))
-		if(az < self.min_az):
-			while(az < self.min_az):
+			self._log.warning('Azimuth corrected to: ' + str(round(float(az), 2)))
+		if az < self.min_az:
+			while az < self.min_az:
 				az += 360
-			logging.warning('Azimuth corrected to: ' + str(round(float(az), 2)))
+			self._log.warning('Azimuth corrected to: ' + str(round(float(az), 2)))
 
-		if(el > self.max_el):
+		if el > self.max_el:
 			el = self.max_el
-			logging.warning('Elevation corrected to: ' + str(round(float(az), 2)))
-		if(el < self.min_el):
+			self._log.warning('Elevation corrected to: ' + str(round(float(az), 2)))
+		if el < self.min_el:
 			el = self.min_el
-			logging.warning('Elevation corrected to: ' + str(round(float(az), 2)))
+			self._log.warning('Elevation corrected to: ' + str(round(float(az), 2)))
 
-		logging.info('##############################')
-		logging.info('# SET COMMAND')
-		logging.info('##############################')
-		logging.info('# Azimuth:   ' + str(round(float(az), 2)))
-		logging.info('# Elevation: ' + str(round(float(el), 2)))
-		logging.info('##############################\n')
+		self._log.debug('Set command to be sent')
+		self._log.debug('-> Azimuth:   ' + str(round(float(az), 2)))
+		self._log.debug('-> Elevation: ' + str(round(float(el), 2)))
 
 		# encode with resolution
 		H = int(self._resolution * (float(az) + 360))
@@ -210,6 +177,7 @@ class ROT2ProgSim:
 	    el (int): Current elevation angle of rotator.
 	"""
 	
+	_log = None
 	_ser = None
 	_retry = 5
 	_keep_running = True
@@ -225,51 +193,37 @@ class ROT2ProgSim:
 		    port (str): Name of serial port to connect to.
 		    resolution (int): Resolution of simulated ROT2Prog controller. Options are 0x1, 0x2, and 0x4.
 		"""
+		self._log = logging.getLogger(__name__)
+
 		# open serial port
-		while self._ser is None:
-			try:
-				self._ser = serial.Serial(
-					port = port,
-					baudrate = 600,
-					bytesize = 8,
-					parity = 'N',
-					stopbits = 1,
-					timeout = None)
-			except:
-				# retry until connection is established
-				logging.error('Connection to serial port failed, retrying in ' + str(self._retry) + ' seconds')
-				time.sleep(self._retry)
+		self._ser = serial.Serial(
+			port = port,
+			baudrate = 600,
+			bytesize = 8,
+			parity = 'N',
+			stopbits = 1,
+			timeout = None)
 
 		self._resolution = resolution
-		logging.info('ROT2Prog simulation interface opened on ' + str(self._ser.name) + '\n')
+		self._log.info('ROT2Prog simulation interface opened on ' + str(self._ser.name))
 
 		# start daemon thread to communicate on serial port
 		Thread(target = self.run, daemon = True).start()
-	
-	def __del__(self):
-		"""Closes serial connection and deletes object.
-		"""
-		if self._ser is not None:
-			self._ser.close()
 
 	def run(self):
 		"""Receives command packets, parses them to update the state of the simulator, and sends response packets when necessary.
 		"""
 		while self._keep_running:
 			command_packet = list(self._ser.read(13))
-			logging.debug('Command packet received: ' + str(command_packet) + '\n')
+			self._log.debug('Command packet received: ' + str(command_packet))
 
 			K = command_packet[11]
 
 			if K in [0x0F, 0x1F]:
 				if K == 0x0F:
-					logging.info('##############################')
-					logging.info('# STOP COMMAND')
-					logging.info('##############################\n')
+					self._log.info('Stop command received')
 				elif K == 0x1F:
-					logging.info('##############################')
-					logging.info('# STATUS COMMAND')
-					logging.info('##############################\n')
+					self._log.info('Status command received')
 
 				# convert to byte values
 				H = "000" + str(round(float(self.az + 360), 1))
@@ -283,19 +237,16 @@ class ROT2ProgSim:
 					self._resolution,
 					0x20]
 
-				logging.info('##############################')
-				logging.info('# RESPONSE')
-				logging.info('##############################')
-				logging.info('# Azimuth:   ' + str(float(self.az)))
-				logging.info('# Elevation: ' + str(float(self.el)))
-				logging.info('# PH: ' + str(self._resolution))
-				logging.info('# PV: ' + str(self._resolution))
-				logging.info('##############################\n')
+				self._log.debug('Response to be sent')
+				self._log.debug('-> Azimuth:   ' + str(float(self.az)))
+				self._log.debug('-> Elevation: ' + str(float(self.el)))
+				self._log.debug('-> PH:        ' + str(self._resolution))
+				self._log.debug('-> PV:        ' + str(self._resolution))
 
 				self._ser.flush()
 				self._ser.write(bytearray(rsp))
 
-				logging.debug('Response packet sent: ' + str(rsp) + '\n')
+				self._log.debug('Response packet sent: ' + str(rsp))
 			elif K == 0x2F:
 				# convert from ascii characters
 				H = (command_packet[1] * 1000) + (command_packet[2] * 100) + (command_packet[3] * 10) + command_packet[4]
@@ -305,14 +256,11 @@ class ROT2ProgSim:
 				self.az = H/self._resolution - 360.0
 				self.el = V/self._resolution - 360.0
 
-				logging.info('##############################')
-				logging.info('# SET COMMAND')
-				logging.info('##############################')
-				logging.info('# Azimuth:   ' + str(self.az))
-				logging.info('# Elevation: ' + str(self.el))
-				logging.info('##############################\n')
+				self._log.info('Set command received')
+				self._log.info('-> Azimuth:   ' + str(self.az))
+				self._log.info('-> Elevation: ' + str(self.el))
 			else:
-				logging.error('Invalid command received [K = ' + str(hex(K)) + ']\n')
+				self._log.error('Invalid command received [K = ' + str(hex(K)) + ']')
 
 	def stop(self):
 		"""Stops the daemon thread running the simulator.
